#
# spec file for package mraa
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 2
Name:           mraa
Version:        2.2.0
Release:        2.12
Summary:        Low Level Skeleton Library for IO Communication
License:        MIT
Group:          Hardware/Other
URL:            https://github.com/eclipse/mraa
Source:         https://github.com/eclipse/mraa/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         mraa-i686.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gtest
BuildRequires:  java-devel
BuildRequires:  javapackages-tools
BuildRequires:  pkgconfig
BuildRequires:  swig
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(python3)
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64

%description
libmraa is a C/C++ library with bindings to Java, Python and JavaScript to
interface with the IO on Galileo, Edison & other platforms, with a
structured and sane API where port names/numbering matches the board that
you are on. Use of libmraa does not tie you to specific hardware with board
detection done at runtime you can create portable code that will work
across the supported platforms.

The intent is to make it easier for developers and sensor manufacturers to
map their sensors & actuators on top of supported hardware and to allow
control of low level communication protocol by high level languages &
constructs.

%package -n lib%{name}%{sover}
Summary:        Low Level Skeleton Library for IO Communication
Group:          System/Libraries

%description -n lib%{name}%{sover}
libmraa is a C/C++ library with bindings to Java, Python and JavaScript to
interface with the IO on Galileo, Edison & other platforms, with a
structured API where port names/numbering matches the board that
you are on. Use of libmraa does not tie you to specific hardware. With board
detection done at runtime, you can create portable code that will work
across the supported platforms.

This package contains shared library for %{name}.

%package devel
Summary:        Development files for %{name}
Group:          Development/Languages/C and C++
Requires:       lib%{name}%{sover} = %{version}

%description devel
libmraa is a C/C++ library with bindings to Java, Python and JavaScript to
interface with the IO on Galileo, Edison & other platforms, with a
structured API where port names/numbering matches the board that
you are on. Use of libmraa does not tie you to specific hardware. With board
detection done at runtime, you can create portable code that will work
across the supported platforms.

This package contains development files for %{name}.

%package -n python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Languages/Python
Requires:       lib%{name}%{sover} = %{version}

%description -n python3-%{name}
libmraa is a C/C++ library with bindings to Java, Python and JavaScript to
interface with the IO on Galileo, Edison & other platforms, with a
structured API where port names/numbering matches the board that
you are on. Use of libmraa does not tie you to specific hardware. With board
detection done at runtime, you can create portable code that will work
across the supported platforms.

This package contains python3 bindings for %{name}.

%package -n java-%{name}
Summary:        Java bindings for %{name}
Group:          Development/Languages/Java
Requires:       javapackages-tools
Requires:       lib%{name}%{sover} = %{version}

%description -n java-%{name}
libmraa is a C/C++ library with bindings to Java, Python and JavaScript to
interface with the IO on Galileo, Edison & other platforms, with a
structured API where port names/numbering matches the board that
you are on. Use of libmraa does not tie you to specific hardware. With board
detection done at runtime, you can create portable code that will work
across the supported platforms.

This package contains java bindings for %{name}.

%package -n nodejs-%{name}
Summary:        Nodes bindings for %{name}
Group:          Development/Languages/Other
%requires_ge    nodejs6

%description -n nodejs-%{name}
libmraa is a C/C++ library with bindings to Java, Python and JavaScript to
interface with the IO on Galileo, Edison & other platforms, with a
structured API where port names/numbering matches the board that
you are on. Use of libmraa does not tie you to specific hardware. With board
detection done at runtime, you can create portable code that will work
across the supported platforms.

This package contains nodejs bindings for %{name}.

%package examples
Summary:        Examples for %{name}
Group:          Hardware/Other

%description examples
libmraa is a C/C++ library with bindings to Java, Python and JavaScript to
interface with the IO on Galileo, Edison & other platforms, with a
structured API where port names/numbering matches the board that
you are on. Use of libmraa does not tie you to specific hardware. With board
detection done at runtime you can create portable code that will work
across the supported platforms.

This package contains examples for %{name}.

%prep
%autosetup

%build
%cmake \
  -DCMAKE_C_FLAGS="%{optflags} -fcommon -DNDEBUG" \
  -DINSTALLTOOLS=yes \
  -DINSTALLGPIOTOOL=yes \
  -DUSBPLAT=yes \
  -DFIRMATA=off \
  -DIMRAA=yes \
  -DFTDI4222=off \
  -DBUILDTESTS=on \
  -DBUILDSWIGPYTHON=on \
  -DBUILDSWIGJAVA=on \
  -DBUILDSWIGNODE=off \
  -Wno-dev
%cmake_build

%install
%cmake_install
install -d %{buildroot}%{_javadir}
mv %{buildroot}%{_prefix}/lib/java/mraa.jar %{buildroot}%{_javadir}/%{name}.jar

%check
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{buildroot}%{_libdir}
%ctest

%post -n lib%{name}%{sover} -p /sbin/ldconfig
%postun -n lib%{name}%{sover} -p /sbin/ldconfig

%files
%license COPYING
%doc README.md
%{_bindir}/imraa
%{_bindir}/mraa-gpio
%{_bindir}/mraa-i2c
%{_bindir}/mraa-uart

%files -n lib%{name}%{sover}
%{_libdir}/libmraa.so.%{sover}
%{_libdir}/libmraa.so.%{version}

%files devel
%{_libdir}/libmraa.so
%{_includedir}/%{name}.*
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc

%files -n python3-%{name}
%{python3_sitearch}/*

%files -n java-%{name}
%{_javadir}/%{name}.jar
%{_libdir}/libmraajava.so
%{_libdir}/pkgconfig/mraajava.pc

%files examples
%{_datadir}/%{name}

%changelog
* Mon Feb  1 2021 Martin Pluskal <mpluskal@suse.com>
- Update project url
* Wed Dec 30 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.2.0:
  * Multiple fixes to improve project security and reliability on
    newly added platforms
  * Removed Python 2 bindings and old node.js versions from CI
  * Added detection for latest RPi board versions
  * Fix for SPI frequency function not writing to file
  * Common mraa API can now return C error strings from MRAA error
    codes
  * Updated and extended installation instructions for some Linux
    distributions
* Mon Nov 16 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add mraa-i686.patch: Support target_arch i686, same as i586.
* Mon Aug 24 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%{_prefix}/lib instead of %%{_libexecdir} (boo#1174075).
* Fri Jun 12 2020 Martin Pluskal <mpluskal@suse.com>
- Fix building with gcc10
* Tue Apr 28 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.1.0:
  * New platforms UP Xtreme, IPi SMARC, ROCK PI 4, Raspberry Pi 4,
    Ultra96
  * Added support for chardev GPIO devices on Rock960
  * Introduced APIs to initialize GPIOs by name
  * Multiple fixes to address static tool scans and user submitted
    bug reports
  * Revised documentation to reflect project transfer to the
    Eclipse Foundation
  * Updated installation instructions for multiple distribution
    channels
- Drop python2 bindings
* Mon Mar 11 2019 Martin Pluskal <mpluskal@suse.com>
- Drop nodejs bindings as they dont work with lates versions of
  node.
* Thu Jan 10 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.0.0:
  * New platforms IEI Tank, Ultra-96, Rock960, Hikey960,
    Dragonboard 820c
  * Added support for chardev GPIO devices with implementation on
    several boards
  * Added string based I/O initialization for simpler integration
    with other frameworks
  * Added GTest support for unit testing
  * Extended named LED device APIs allowing them to be listed
    during board definition
  * Removed packaging and CI for obsolete devkits
  * Multiple bug fixes and cmake improvements
- Run tests during build
* Tue Jul 10 2018 mpluskal@suse.com
- Update to version 1.9.0:
  * Added support for RPi Zero W
  * Added support for MIPS based Omega2 and Linkit Smart 7688
  * New APIs for sysfs onboard LED control using the gpio-leds
    driver
  * Restructured and cleaned-up examples
  * Improved documentation generation and CI integration
  * Static analysis fixes, added SonarQube badge
  * Enhanced Node.js detection on some Linux distros (OpenSUSE)
- Enable building of nodejs bindings
* Mon Nov 13 2017 mpluskal@suse.com
- Use consistent naming with singlespec python packages
- Build tests as well
* Thu Oct 26 2017 mpluskal@suse.com
- Update to version 1.8.0:
  * Added Up2 support & grovePi subplatform support
  * Various improvements on 96board, rpi, beaglebone & Up boards
  * CMake 3.8+ improvements
  * Peripheral I/O improvements
  * Json platform improvements
  * Static analysis cleanup using SonarQube
* Mon Jun  5 2017 mpluskal@suse.com
- Update to version 1.7.0:
  * Peripheral I/O support for Android Things
  * Deprecation of node v0.10.x and 0.12.x
  * Documetnatino improvements
* Fri Apr 21 2017 mpluskal@suse.com
- Update to version 1.6.1:
  * mraa-deinit bug fix
  * rpi3 fix
  * ALTERA_SOCFPGA -> DE_NANO_SOC
- Changes for version 1.6.0:
  * de-10 nano board support
  * Improved Intel Joule support & renamed from GT_TUCHUCK to Joule
  * Improved RPI3 support
  * Fixes for UP, 96boards & phyboard-wega
  * Call mraa_deinit with a gcc destructor attribute
- Drop upstreamed patches:
  * 0001-rpi-fix-PLATFORM_RASPBERRY_PI_ZERO-value.patch
  * 0002-examples-add-return-in-spi_max7219.c.patch
  * 0003-arm-prefer-proc-device-tree.patch
  * 0004-rpi-use-proc-device-tree-compatible.patch
  * 0005-raspberrypi-add-3-model-B-support.patch
  * 0006-rpi-take-care-of-gpiochip-base.patch
* Tue Feb 28 2017 cbosdonnat@suse.com
- Fix build for aarch64
    0001-rpi-fix-PLATFORM_RASPBERRY_PI_ZERO-value.patch
    0002-examples-add-return-in-spi_max7219.c.patch
- Get mraa working on raspberry pi
    0003-arm-prefer-proc-device-tree.patch
    0004-rpi-use-proc-device-tree-compatible.patch
    0005-raspberrypi-add-3-model-B-support.patch
    0006-rpi-take-care-of-gpiochip-base.patch
* Thu Jan 26 2017 mpluskal@suse.com
- Update to version 1.5.1:
  * Small memleaks plugged
  * imraa useless arp statements removed
  * NPM 1.5.0 did not 100%% match real 1.5.0 tag, this resolves this
- Changes for version 1.5.0:
  * imraa now uses argp, slight option changes, you need to use -a
    to flash a 101
  * Joule i2c enumeration much improved, uses pci id
  * Firmata add a spinlock to remove possible race condition
  * Mock Uart functionality
- Changes for version 1.4.0:
  * Add support for Siemens SIMATIC IOT2000
  * Cmake now enables much more error detection depending on
    compiler support
  * Mraa Maven packages now enabled
  * Galileo Gen2 AIO fix using pincmd
  * Adding an already added firmata platform now returns
    MRAA_SUCCESS
  * Cmake no longer tags builds without git as '-dirty' version.c
    for easier packaging support
- Changes for version 1.3.0:
  * Fix GT GPIO bugs
  * Mock SPI and travis now uses mock and tests it
  * RPI zero support
* Wed Aug 17 2016 jengelh@inai.de
- Update descriptions and rpm groups.
* Wed Aug 17 2016 mpluskal@suse.com
- Initial package for version 1.2.3
